---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: ''
assignees: ''
---

<!--- Remove sections that do not apply -->
<!--- Advice for the reporter: Please use this template to report bugs or feature requests only. -->

Issues should only be created for bugs, feature requests, or other topics
related to the **development** of the project. For general questions, please use
the
[Discussions](https://github.com/retigra/ZabbixCI/discussions/categories/q-a)
section.

<!--- Provide a general summary of the issue in the Title above -->

## Wanted Behavior

<!--- Tell us what should happen -->

## Current Behavior (if any)

<!--- Tell us what happens instead of the expected behavior -->

## Context (Environment)

- ZabbixCI version:
- Zabbix version:
- Python version:
- Operating system version:
